<?php
/**
 * A class for the page providing the subscription settings.
 * 
 * @author Paul Kashtanoff <paul@byonepress.com>
 * @copyright (c) 2014, OnePress Ltd
 * 
 * @package core 
 * @since 1.0.0
 */

/**
 * The Subscription Settings
 * 
 * @since 1.0.0
 */
class OPanda_SubscriptionSettings extends OPanda_Settings  {
 
    public $id = 'subscription';
    
    public function init() {

        if ( isset( $_GET['opanda_aweber_disconnected'] )) {
            $this->success = __('Your Aweber Account has been successfully disconnected.', 'optinpanda');
        }
    }
    
    /**
     * Shows the header html of the settings screen.
     * 
     * @since 1.0.0
     * @return void
     */
    public function header() {
        ?>
        <p><?php _e('Set up here how you would like to save emails of your subscribers.', 'optionpanda') ?></p>
        <?php
    }
    
    /**
     * Returns subscription options.
     * 
     * @since 1.0.0
     * @return mixed[]
     */
    public function getOptions() {
        
        $options = array();
        
        $options[] = array(
            'type' => 'separator'
        );
        
        require_once OPANDA_BIZPANDA_DIR . '/admin/includes/subscriptions.php';
        $serviceList = OPanda_SubscriptionServices::getSerivcesList();
        
        // fix
        $service =  get_option('opanda_subscription_service', 'database');
        if ( $service == 'none' ) update_option('opanda_subscription_service', 'database');
        
        $listItems = array();
        
        foreach( $serviceList as $serviceName => $serviceInfo ) {
            
            $listItems[] = array(
                'value' => $serviceName,
                'title' => $serviceInfo['title'],
                'hint' => isset( $serviceInfo['description'] ) ? $serviceInfo['description'] : null,
                'image' => isset( $serviceInfo['image'] ) ? $serviceInfo['image'] : null,
                'hover' => isset( $serviceInfo['hover'] ) ? $serviceInfo['hover'] : null             
            );
        }
        
        $options[] = array(
            'type' => 'dropdown',
            'name' => 'subscription_service',
            'way' => 'ddslick',
            'width' => 450,
            'data' => $listItems,
            'default' => 'none',
            'title' => __('Mailing Service', 'optinpanda')
        );
        
        // mailchimp
        
        $options[] = array(
            'type'      => 'div',
            'id'        => 'opanda-mailchimp-options',
            'class'     => 'opanda-mail-service-options opanda-hidden',
            'items'     => array(

                array(
                    'type' => 'separator'
                ),
                array(
                    'type'      => 'textbox',
                    'name'      => 'mailchimp_apikey',
                    'after'     => sprintf( __( '<a href="%s" class="btn btn-default" target="_blank">Get API Key</a>', 'optinpanda' ), 'http://kb.mailchimp.com/accounts/management/about-api-keys#Finding-or-generating-your-API-key' ),
                    'title'     => __( 'API Key', 'optinpanda' ),
                    'hint'      => __( 'The API key of your MailChimp account.', 'optinpanda' ),
                )
            )
        );
        
        // aweber
        
        if( !$this->isAweberConnected()) {
            
            $options[] = array(
                'type'      => 'div',
                'id'        => 'opanda-aweber-options',
                'class'     => 'opanda-mail-service-options opanda-hidden',
                'items'     => array(

                    array(
                        'type' => 'separator'
                    ),
                    array(
                        'type'      => 'html',
                        'html'      => array($this, 'showAweberHtml')
                    ),
                    array(
                        'type'      => 'textarea',
                        'name'      => 'aweber_auth_code',
                        'title'     => __( 'Authorization Code', 'optinpanda' ),
                        'hint'      => __( 'The authorization code you will see after log in to your Aweber account.', 'optinpanda' )
                    )
                )
            );    
            
        } else {
            
            $options[] = array(
                'type'      => 'div',
                'id'        => 'opanda-aweber-options',
                'class'     => 'opanda-mail-service-options opanda-hidden',
                'items'     => array(
                    array(
                        'type' => 'separator'
                    ),
                    array(
                        'type'      => 'html',
                        'html'      => array($this, 'showAweberHtml')
                    )                    
                )
            );
        }
        
        // getresponse
        
        $options[] = array(
            'type'      => 'div',
            'id'        => 'opanda-getresponse-options',
            'class'     => 'opanda-mail-service-options opanda-hidden',
            'items'     => array(
                
                array(
                    'type' => 'separator'
                ),
                array(
                    'type'      => 'textbox',
                    'name'      => 'getresponse_apikey',
                    'title'     => __( 'API Key', 'optinpanda' ),
                    'after'     => sprintf( __( '<a href="%s" class="btn btn-default" target="_blank">Get API Key</a>', 'optinpanda' ), 'http://support.getresponse.com/faq/where-i-find-api-key' ),
                    'hint'      => __( 'The Twitter Consumer Secret of your Twitter App.', 'optinpanda' )
                )
            )
        );

        // mymail
        
        $options[] = array(
            'type'      => 'div',
            'id'        => 'opanda-mymail-options',
            'class'     => 'opanda-mail-service-options opanda-hidden',
            'items'     => array(
                
       
                array(
                    'type' => 'html',
                    'html' => array($this, 'showMyMailHtml')
                ),
                array(
                    'type' => 'separator'
                ),
                array(
                    'type'      => 'checkbox',
                    'way'       => 'buttons',
                    'name'      => 'mymail_redirect',
                    'title'     => __( 'Redirect To Locker', 'optinpanda' ),
                    'hint'      => sprintf( __( 'Set On to redirect the user after the email confirmation to the page where the locker located.<br />If Off, the MyMail will redirect the user to the page specified in the option <a href="%s" target="_blank">Newsletter Homepage</a>.', 'optinpanda' ), admin_url('options-general.php?page=newsletter-settings&settings-updated=true#frontend') )
                )
            )
        );
        
        // mailpoet
        
        $options[] = array(
            'type'      => 'div',
            'id'        => 'opanda-mailpoet-options',
            'class'     => 'opanda-mail-service-options opanda-hidden',
            'items'     => array(
     
                array(
                    'type' => 'html',
                    'html' => array($this, 'showMailPoetHtml')
                )   
            )
        );
        
        // acumbamail
        
        $options[] = array(
            'type'      => 'div',
            'id'        => 'opanda-acumbamail-options',
            'class'     => 'opanda-mail-service-options opanda-hidden',
            'items'     => array(
                
                array(
                    'type' => 'separator'
                ),
                array(
                    'type'      => 'textbox',
                    'name'      => 'acumbamail_customer_id',
                    'title'     => __( 'Customer ID', 'optinpanda' ),
                    'after'     => sprintf( __( '<a href="%s" class="btn btn-default" target="_blank">Get ID & Token</a>', 'optinpanda' ), 'https://acumbamail.com/apidoc/' ),
                    'hint'      => __( 'The customer ID of your Acumbamail account.', 'optinpanda' )
                ),
                array(
                    'type'      => 'textbox',
                    'name'      => 'acumbamail_api_token',
                    'title'     => __( 'API Token', 'optinpanda' ),
                    'hint'      => __( 'The API token of your Acumbamail account.', 'optinpanda' )
                )
            )
        );
        
        // knews
        
        $options[] = array(
            'type'      => 'div',
            'id'        => 'opanda-knews-options',
            'class'     => 'opanda-mail-service-options opanda-hidden',
            'items'     => array(
     
                array(
                    'type' => 'html',
                    'html' => array($this, 'showKNewsHtml')
                ),
                array(
                    'type' => 'separator'
                ),
                array(
                    'type'      => 'checkbox',
                    'way'       => 'buttons',
                    'name'      => 'knews_redirect',
                    'title'     => __( 'Redirect To Locker', 'optinpanda' ),
                    'hint'      => __( 'Set On to redirect the user after the email confirmation to the page where the locker located.<br />If Off, the K-news will redirect the user to the home page.', 'optinpanda' )
                )   
            )
        );   
        
        // freshmail
        
        $options[] = array(
            'type'      => 'div',
            'id'        => 'opanda-freshmail-options',
            'class'     => 'opanda-mail-service-options opanda-hidden',
            'items'     => array(

                array(
                    'type' => 'separator'
                ),
                array(
                    'type'      => 'textbox',
                    'name'      => 'freshmail_apikey',
                    'title'     => __( 'API Key', 'optinpanda' ),
                    'after'     => sprintf( __( '<a href="%s" class="btn btn-default" target="_blank">Get API Keys</a>', 'optinpanda' ), 'https://app.freshmail.com/en/settings/integration/' ),
                    'hint'      => __( 'The API Key of your FreshMail account.', 'optinpanda' )
                ),
                array(
                    'type'      => 'textbox',
                    'name'      => 'freshmail_apisecret',
                    'title'     => __( 'API Secret', 'optinpanda' ),
                    'hint'      => __( 'The API Sercret of your FreshMail account.', 'optinpanda' )
                )
            )
        );
        
        // sendy
        
        $options[] = array(
            'type'      => 'div',
            'id'        => 'opanda-sendy-options',
            'class'     => 'opanda-mail-service-options opanda-hidden',
            'items'     => array(

                array(
                    'type' => 'separator'
                ),
                array(
                    'type'      => 'textbox',
                    'name'      => 'sendy_apikey',
                    'title'     => __( 'API Key', 'optinpanda' ),
                    'hint'      => __( 'The API key of your Sendy application, available in Settings.', 'optinpanda' ),
                ),
                array(
                    'type'      => 'textbox',
                    'name'      => 'sendy_url',
                    'title'     => __( 'Installation', 'optinpanda' ),
                    'hint'      => __( 'An URL for your Sendy installation, <strong>http://your_sendy_installation</strong>', 'optinpanda' ),
                )
            )
        );
        
        $options[] = array(
            'type' => 'separator'
        );
        
        return $options;
    }
    
    public function showAweberHtml() {
        
        if( !$this->isAweberConnected()) {
        ?>
        
        <div class="form-group">
            <label class="col-sm-2 control-label"></label>
            <div class="control-group controls col-sm-10 opanda-aweber-steps">
                <p><?php _e( 'To connect your Aweber account:', 'optinpanda' ) ?></p>
                <ul>
                    <li><?php _e( '<span>1.</span> <a href="https://auth.aweber.com/1.0/oauth/authorize_app/92c68137" class="button" target="_blank">Click here</a> <span>to open the authorization page and log in.</span>', 'optinpanda' ) ?></li>
                    <li><?php _e( '<span>2.</span> Copy and paste the authorization code in the field below.', 'optinpanda' ) ?></li>
                </ul>
            </div>
        </div>
        
        <?php } else { ?>
        
        <div class="form-group">
            <label class="col-sm-2 control-label"></label>
            <div class="control-group controls col-sm-10 opanda-aweber-steps">
                <p><strong><?php _e( 'Your Aweber Account is connected.', 'optinpanda' ) ?></strong></p>
                <ul>
                    <li><?php _e( '<a href="' . $this->getActionUrl('disconnectAweber') . '" class="button onp-sl-aweber-oauth-logout">Click here</a> <span>to disconnect.</span>', 'optinpanda' ) ?></li>                    
                </ul>
            </div>
        </div>
        
        <?php  
        }
    }
    
    /**
     * Shows HTML for MyMail.
     * 
     * @since 1.0.7
     * @return void
     */
    public function showMyMailHtml() {
        
        if ( !defined('MYMAIL_VERSION') ) {
            ?>
            <div class="form-group">
                <label class="col-sm-2 control-label"></label>
                <div class="control-group controls col-sm-10">
                    <p><strong><?php _e('The MyMail plugin is not found on your website. Emails will not be saved.', 'opanda') ?></strong></p>
                </div>
            </div>
            <?php
        } else {
            ?>
            <div class="form-group">
                <label class="col-sm-2 control-label"></label>
                <div class="control-group controls col-sm-10">
                    <p><?php _e('You can set a list where the subscribers should be added in the settings of a particular locker.', 'opanda') ?></p>
                </div>
            </div>
        <?php
        }
    }
    
    /**
     * Shows HTML for MyMail.
     * 
     * @since 1.0.7
     * @return void
     */
    public function showMailPoetHtml() {
        
        if ( !defined('WYSIJA') ) {
            ?>
            <div class="form-group">
                <label class="col-sm-2 control-label"></label>
                <div class="control-group controls col-sm-10">
                    <p><strong><?php _e('The MailPoet plugin is not found on your website. Emails will not be saved.', 'opanda') ?></strong></p>
                </div>
            </div>
            <?php
        } else {
            ?>
            <div class="form-group">
                <label class="col-sm-2 control-label"></label>
                <div class="control-group controls col-sm-10">
                    <p><?php _e('You can set a list where the subscribers should be added in the settings of a particular locker.', 'opanda') ?></p>
                </div>
            </div>
        <?php
        }
    }
    
    /**
     * Shows HTML for Knews.
     * 
     * @since 1.0.7
     * @return void
     */
    public function showKNewsHtml() {
        
        if ( !class_exists("KnewsPlugin") ) {
            ?>
            <div class="form-group">
                <label class="col-sm-2 control-label"></label>
                <div class="control-group controls col-sm-10">
                    <p><strong><?php _e('The K-news plugin is not found on your website. Emails will not be saved.', 'opanda') ?></strong></p>
                </div>
            </div>
            <?php
        } else {
            ?>
            <div class="form-group">
                <label class="col-sm-2 control-label"></label>
                <div class="control-group controls col-sm-10">
                    <p><?php _e('You can set a list where the subscribers should be added in the settings of a particular locker.', 'opanda') ?></p>
                </div>
            </div>
        <?php
        }
    }
    
    /**
     * Calls before saving the settings.
     * 
     * @since 1.0.0
     * @return void
    */
    public function onSaving() {
        
        $service = isset( $_POST['opanda_subscription_service'] ) 
                ? $_POST['opanda_subscription_service']:
                null;
        
        $authCode = isset( $_POST['opanda_aweber_auth_code'] )
                ? trim( $_POST['opanda_aweber_auth_code'] ):
                null;
        
        unset( $_POST['opanda_aweber_auth_code'] );
        
        if ( 'aweber' !== $service || $this->isAweberConnected() ) return;
        
        // if the auth code is empty, show the error
        
        if ( empty( $authCode ) ) {
            return $this->showError( __('Unable to connect to Aweber. The Authorization Code is empty.', 'optinpanda' ) );    
        }
        
        // try to get credential via api, shows the error if the exception occurs

        require_once OPANDA_BIZPANDA_DIR.'/admin/includes/subscriptions.php';
        $aweber = OPanda_SubscriptionServices::getService('aweber');
        
        try {
            $credential = $aweber->getCredentialUsingAuthorizeKey( $authCode ); 
        } catch (Exception $ex) {
            return $this->showError( $ex->getMessage() );
        }

        // saves the credential

        if ( $credential && sizeof($credential) ) {
            foreach( $credential as $key => $value ) {
                update_option('opanda_aweber_'.$key, $value);
            }
        }
   }
    
    public function isAweberConnected() {
         return get_option('opanda_aweber_consumer_key', false);
    }   
   
    public function disconnectAweberAction() {

        delete_option('opanda_aweber_consumer_key');
        delete_option('opanda_aweber_consumer_secret');
        delete_option('opanda_aweber_access_key');
        delete_option('opanda_aweber_access_secret');
        delete_option('opanda_aweber_auth_code'); 
        delete_option('opanda_aweber_account_id'); 
        
        return $this->redirectToAction('index', array('opanda_aweber_disconnected' => true));
    }
}
